<?php
$scc_team_taxonomy = 'scc-team-positions';

$scc_team = array();
array_push($scc_team, array(
    "title" => "Team",
    "title_singular" => "Team Member",
    "slug"  => "scc-team",
    "taxonomy" => $scc_team_taxonomy
));

add_action('init', 'register_cpt_scc_team');
add_action('admin_menu', 'scc_team_menu');
add_action('admin_init', 'scc_team_create_custom_fields');
add_action('save_post_scc-team', 'scc_team_save_custom_fields');

function register_cpt_scc_team(){
    global $scc_team;
    global $scc_team_taxonomy;

    foreach($scc_team as $item):
        //In The News custom post type ------------------------
        $labels = array(
            'name' => _x( $item['title'], $item['slug'] ),
            'singular_name' => _x( $item['title_singular'], $item['slug']),
            'add_new' => _x( 'Add New', $item['slug'] ),
            'add_new_item' => _x( 'Add New ' . $item['title_singular'], $item['slug'] ),
            'edit_item' => _x( 'Edit ' . $item['title_singular'], $item['slug'] ),
            'new_item' => _x( 'New ' . $item['title_singular'], $item['slug'] ),
            'view_item' => _x( 'View ' . $item['title_singular'], $item['slug'] ),
            'search_items' => _x( 'Search ' . $item['title'], $item['slug'] ),
            'not_found' => _x( 'No ' . $item['title'] . ' found', $item['slug'] ),
            'not_found_in_trash' => _x( 'No ' . $item['title'] . ' found in Trash', $item['slug'] ),
            'parent_item_colon' => _x( 'Parent ' . $item['title'], $item['slug'] ),
            'menu_name' => _x( $item['title'], $item['slug'] ),
        );

        $args = array(
            'labels'              => $labels,
            'hierarchical'        => false,
            'description'         => $item['title'] . ' Articles',
            'supports'            => array( 'title', 'editor' ),
            'taxonomies'          => array( $scc_team_taxonomy ),
            'public'              => true,
            'show_ui'             => true,
            'show_in_menu'        => true,
            'show_in_nav_menus'   => true,
            'menu_position'       => 6,
            'menu_icon'           => 'dashicons-groups',
            'publicly_queryable'  => true,
            'exclude_from_search' => true,
            'rewrite'             => true,
            'has_archive'         => true,
            'query_var'           => true,
            'can_export'          => true,
            'capability_type'     => 'post'
        );

        register_taxonomy(
            $scc_team_taxonomy,
            $item['slug'],
            array(
                'label' => __( 'Position' ),
                'rewrite' => array( 'slug' => 'scc-team' ),
                'hierarchical' => true,
                'show_admin_column' => true
            )
        );

        register_post_type( $item['slug'], $args );
    endforeach;
}
function scc_team_menu(){
    //add_filter('manage_scc-team_posts_columns', 'scc_team_define_columns');
    //add_action('manage_scc-team_posts_custom_column', 'scc_team_get_custom_column_data', 10, 2);
}

function scc_team_define_columns($defaults){
    $defaults['member_position'] = 'Position';
    $defaults['id'] = 'ID';
    return $defaults;
}

function scc_team_get_custom_column_data($column_name, $post_ID){
    global $scc_team_taxonomy;

    if ($column_name == 'member_position') {
        $post_terms_ary = wp_get_post_terms($post_ID,$scc_team_taxonomy);
        $post_terms = array();
        if($post_terms_ary){
            foreach($post_terms_ary as $term){
                array_push($post_terms,$term->name);
            }

            $post_terms = implode(',',$post_terms);

            echo $post_terms;
        }
    }
    if($column_name == "id"){
        echo $post_ID;
    }
}

function render_scc_team_page(){
    global $scc_team;
    global $post;

    echo '<div class="wrap">';
    echo '<h1>Team Page</h1>';

    foreach($scc_team as $group) {

        $queryTeam = new WP_Query(array(
            'post_type' => $group['slug'],
            'posts_per_page' => -1,
            'orderby' => 'menu_order',
            'order' => 'ASC'
        ));

        if ($queryTeam->have_posts()):
            echo '<div class="team-members--container">';
            echo '<h3>' . $group['title'] . '</h3>';

            while ($queryTeam->have_posts()) : $queryTeam->the_post();

                //custom fields
                //file_attachment, web_link, date_display
                $customFields = get_post_custom($post->ID);

                $member = array(
                    "name"          => get_the_title(),
                    "photo"         => isset($customFields['member_picture'][0]) ? $customFields['member_picture'][0] : "",
                    "company_title" => isset($customFields['company_title'][0]) ? $customFields['company_title'][0] : "",
                    "edit_url"      => get_edit_post_link($post->ID)
                );

                ob_start(); ?>

                <div class="team-member"><!-- onclick shows bio desc.  Clicking marks as active -->

                    <div class="team-image">
                        <a href="<?php echo $member['edit_url'];?>">
                            <img src="<?php echo $member['photo']; ?>" alt="<?php echo $member['name'] ?>"/>
                        </a>
                    </div>

                    <div class="team-text">
                        <div class="team-name"><?php echo $member['name'] ?></div>
                        <div class="team-title"><?php echo $member['company_title'] ?></div>
                    </div>
                </div>

                <?php
                $sc = ob_get_contents();

                ob_end_clean();

                echo $sc;
            endwhile;
            echo '<div class="clearFix"></div></div>';
        endif;
    }

    echo '</div>';//end "wrap"
}


/* =================================
 * ***** CUSTOM FIELDS ******
 * =================================
 */

//change "title" post display text so it indicates you need to enter a name
add_filter('gettext','scc_team_custom_enter_title');//change post title help-display text
function scc_team_custom_enter_title( $input ) {
    global $post_type;
    global $scc_team;
    $display_text = "Enter member name";

    if( is_admin() && 'Enter title here' == $input){
        foreach($scc_team as $group){
            if($group['slug'] == $post_type){
                return $display_text;
            }
        }
    }

    return $input;
}

function scc_team_create_custom_fields(){
    global $scc_team;

    foreach ($scc_team as $item) {
        add_meta_box('member_info', 'Member Info', 'scc_team_customField_memberInfo', $item['slug'], 'side', 'low');
        add_meta_box('social_media', 'Social Media', 'scc_team_customField_socialMedia', $item['slug'], 'normal', 'low');
    }

}

function scc_team_customField_socialMedia(){
    global $post;

    $custom = get_post_custom($post->ID);
    $socialMedia_blank = array(
        "facebook" => '',
        "googleplus" => '',
        "twitter" => '',
        "pintrest" => '',
        "linkedin" => '',
        "instagram" => '',
        "youtube" => '',
        "tumblr" => '',
        "website" => ''
    );
    $socialMedia = isset($custom['social_media'][0]) ? unserialize($custom['social_media'][0]) : $socialMedia_blank;

    //TODO: Might need to do an isset check on all array items to prevent an error from throwing

    ?>
    <p><strong>Team Member's Practice Website:</strong></p>
    <input type="text" name="practice_website" placeholder="http://" value="<?php echo $socialMedia['website'];?>">

    <p><strong>Social Media links for Team Member or his/her practice:</strong></p>
    <ul class="social-media-entry">
        <li><i class="zmdi zmdi-facebook-box icon-facebook"></i><input type="text" name="facebook" placeholder="facebook" value="<?php echo $socialMedia['facebook'];?>"></li>
        <li><i class="zmdi zmdi-google-plus-box icon-googleplus"></i><input type="text" name="googleplus" placeholder="Google+" value="<?php echo $socialMedia['googleplus'];?>"></li>
        <li><i class="zmdi zmdi-twitter-box icon-twitter"></i><input type="text" name="twitter" placeholder="Twitter" value="<?php echo $socialMedia['twitter'];?>"></li>
        <li><i class="zmdi zmdi-pinterest-box icon-pintrest"></i><input type="text" name="pintrest" placeholder="Pintrest" value="<?php echo $socialMedia['pintrest'];?>"></li>
        <li><i class="zmdi zmdi-linkedin-box icon-linkedin"></i><input type="text" name="linkedin" placeholder="Linkedin" value="<?php echo $socialMedia['linkedin'];?>"></li>
        <li><i class="zmdi zmdi-instagram icon-instagram"></i><input type="text" name="instagram" placeholder="Instagram" value="<?php echo $socialMedia['instagram'];?>"></li>
        <li><i class="zmdi zmdi-youtube-play icon-youtube"></i><input type="text" name="youtube" placeholder="YouTube" value="<?php echo $socialMedia['youtube'];?>"></li>
        <li><i class="zmdi zmdi-tumblr icon-tumblr"></i><input type="text" name="tumblr" placeholder="Tumblr" value="<?php echo $socialMedia['tumblr'];?>"></li>
    </ul>

    <?php
}
function scc_team_customField_memberInfo(){
    global $post;

    $custom = get_post_custom($post->ID);
    $company_title = isset($custom['company_title'][0]) ? $custom['company_title'][0] : "";
    $member_picture = isset($custom['member_picture'][0]) ? $custom['member_picture'][0] : "";

    ?>
    <p><strong>Member Photo</strong></p>
    <div class="media-uploader">
        <input class="media-uploader--file-url" name="member_picture" type="hidden"
               value="<?php echo $member_picture; ?>"/>
        <button class="button button-primary media-uploader--upload-button">Add file or Browse...</button>
    </div>

    <div>
        <p><strong>Company Title (ex: CEO)</strong></p>
        <input class="input-wide" type="text" name="company_title" value="<?php echo $company_title;?>" style="width: 100%;"/>
    </div>
    <?php
}

function scc_team_save_custom_fields(){
    global $post;
	$post_type = get_post_type($post);

	if(isset($_POST['save']) || isset($_POST['publish']) && $post_type=="scc-team"){
        $socialMedia = array(
            "facebook"   => isset($_POST['facebook']) ? $_POST['facebook'] : '',
            "googleplus" => isset($_POST['googleplus']) ? $_POST['googleplus'] : '',
            "twitter"    => isset($_POST['twitter']) ? $_POST['twitter'] : '',
            "pintrest"   => isset($_POST['pintrest']) ? $_POST['pintrest'] : '',
            "linkedin"   => isset($_POST['linkedin']) ? $_POST['linkedin'] : '',
            "instagram"  => isset($_POST['instagram']) ? $_POST['instagram'] : '',
            "youtube"  => isset($_POST['youtube']) ? $_POST['youtube'] : '',
            "tumblr"  => isset($_POST['tumblr']) ? $_POST['tumblr'] : '',
            "practice_website"  => isset($_POST['practice_website']) ? $_POST['practice_website'] : '',
        );
        update_post_meta($post->ID, 'company_title', $_POST['company_title']);
        update_post_meta($post->ID, 'member_picture', $_POST['member_picture']);
        update_post_meta($post->ID, 'social_media', $socialMedia);
    }
}